@@ -32,8 +32,8 @@ class Customer(Model):
         auto_author = 'owner'
         owner_field = 'owner'
         anonymous_perms = []
-        authenticated_perms = []
-        owner_perms = ['view', 'add', 'change', 'delete']
+        authenticated_perms = ['add']
+        owner_perms = ['inherit', 'view', 'change', 'delete']
         permission_classes = [CustomerPermissions]
 
     def __str__(self):
@@ -140,7 +140,7 @@ def fix_user_hubl_workaround_493(sender, instance, **kwargs):
 
 @receiver(pre_save, sender=Project)
 def set_jabberid(sender, instance, **kwargs):
-    if settings.JABBER_DEFAULT_HOST and not instance.jabberID:
+    if isinstance(getattr(settings, 'JABBER_DEFAULT_HOST', False), str) and not instance.jabberID:
         instance.jabberID = '{}@conference.{}'.format(
             ''.join(
                 [
